@@ -18,6 +18,7 @@
  * along with GNU Mes.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <mes/lib.h>
 #include <linux/syscall.h>
 #include <syscall.h>
 #include <time.h>
@@ -25,5 +26,7 @@
 int
 clock_gettime (clockid_t clk_id, struct timespec *tp)
 {
-  return _sys_call2 (SYS_clock_gettime, (long) clk_id, (long) tp);
+  long long_clk_id = cast_int_to_long (clk_id);
+  long long_tp = cast_voidp_to_long (tp);
+  return _sys_call2 (SYS_clock_gettime, long_clk_id, long_tp);
 }
