@@ -1,6 +1,6 @@
 /* -*-comment-start: "//";comment-end:""-*-
  * GNU Mes --- Maxwell Equations of Software
- * Copyright © 2016,2017,2018,2019 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+ * Copyright © 2016,2017,2018,2019,2020 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
  *
  * This file is part of GNU Mes.
  *
@@ -33,10 +33,3 @@ ioctl (int filedes, unsigned long command, ...)
   va_end (ap);
   return r;
 }
-
-int
-ioctl3 (int filedes, unsigned long command, long data)
-{
-  int r = _sys_call3 (SYS_ioctl, filedes, command, data);
-  return r;
-}
