@@ -1,6 +1,6 @@
 /* -*-comment-start: "//";comment-end:""-*-
  * GNU Mes --- Maxwell Equations of Software
- * Copyright © 2017,2018 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+ * Copyright © 2017,2018,2022 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
  *
  * This file is part of GNU Mes.
  *
@@ -24,11 +24,14 @@ void *
 memchr (void const *block, int c, size_t size)
 {
   char const *p = block;
-  while (size--)
+
+  while (size != 0)
     {
-      if (c == *p)
-        return (void *) p;
-      p++;
+      size = size - 1;
+      if (c == p[0])
+        return (void*) p;
+      p = p + 1;
     }
+
   return 0;
 }
